@@ -108,8 +108,9 @@ func (cmd CloneCmd) Exec(ctx context.Context, commandStr string, args []string,
 	remoteName := apr.GetValueOrDefault(remoteParam, "origin")
 	branch := apr.GetValueOrDefault(branchParam, "")
 	dir, urlStr, verr := parseArgs(apr)
+	userDirExists, _ := dEnv.FS.Exists(dir)
 
-	scheme, remoteUrl, err := getAbsRemoteUrl(dEnv.FS, dEnv.Config, urlStr)
+	scheme, remoteUrl, err := env.GetAbsRemoteUrl(dEnv.FS, dEnv.Config, urlStr)
 
 	if err != nil {
 		verr = errhand.BuildDError("error: '%s' is not valid.", urlStr).Build()
@@ -141,10 +142,17 @@ func (cmd CloneCmd) Exec(ctx context.Context, commandStr string, args []string,
 						}
 					}
 
-					// Make best effort to delete the directory we created.
 					if verr != nil {
-						_ = os.Chdir("../")
-						_ = dEnv.FS.Delete(dir, true)
+						// If we're cloning into a directory that already exists do not erase it. Otherwise
+						// make best effort to delete the directory we created.
+						if userDirExists {
+							// Set the working dir to the parent of the .dolt folder so we can delete .dolt
+							_ = os.Chdir(dir)
+							_ = dEnv.FS.Delete(dbfactory.DoltDir, true)
+						} else {
+							_ = os.Chdir("../")
+							_ = dEnv.FS.Delete(dir, true)
+						}
 					}
 				}
 			}
