@@ -30,6 +30,7 @@ import (
 type SessionStateAdapter struct {
 	session *Session
 	dbName  string
+	remotes map[string]env.Remote
 }
 
 func (s SessionStateAdapter) UpdateStagedRoot(ctx context.Context, newRoot *doltdb.RootValue) error {
@@ -72,8 +73,8 @@ var _ env.RepoStateReader = SessionStateAdapter{}
 var _ env.RepoStateWriter = SessionStateAdapter{}
 var _ env.RootsProvider = SessionStateAdapter{}
 
-func NewSessionStateAdapter(session *Session, dbName string) SessionStateAdapter {
-	return SessionStateAdapter{session: session, dbName: dbName}
+func NewSessionStateAdapter(session *Session, dbName string, remotes map[string]env.Remote) SessionStateAdapter {
+	return SessionStateAdapter{session: session, dbName: dbName, remotes: remotes}
 }
 
 func (s SessionStateAdapter) GetRoots(ctx context.Context) (doltdb.Roots, error) {
@@ -111,3 +112,15 @@ func (s SessionStateAdapter) GetMergeCommit(ctx context.Context) (*doltdb.Commit
 func (s SessionStateAdapter) GetPreMergeWorking(ctx context.Context) (*doltdb.RootValue, error) {
 	return s.session.dbStates[s.dbName].WorkingSet.MergeState().PreMergeWorkingRoot(), nil
 }
+
+func (s SessionStateAdapter) GetRemotes() (map[string]env.Remote, error) {
+	return s.remotes, nil
+}
+
+func (s SessionStateAdapter) AddRemote(name string, url string, fetchSpecs []string, params map[string]string) error {
+	return fmt.Errorf("cannot insert remote in an SQL session")
+}
+
+func (s SessionStateAdapter) RemoveRemote(ctx context.Context, name string) error {
+	return fmt.Errorf("cannot delete remote in an SQL session")
+}
